@@ -1,4 +1,6 @@
 
+from io import StringIO
+from html.parser import HTMLParser
 import json
 import os
 import re
@@ -7,20 +9,12 @@ import shutil
 
 import traitlets
 
-from ..widgets import IntSlider, IntText, Text, Widget, jslink, HBox, widget_serialization
+# This has a byproduct of setting up the comms
+import ipykernel.ipkernel
+
+from ..widgets import IntSlider, IntText, Text, Widget, jslink, HBox, widget_serialization, widget as widget_module
 from ..embed import embed_data, embed_snippet, embed_minimal_html, dependency_state
 
-try:
-    from io import StringIO
-except ImportError:
-    from StringIO import StringIO
-
-try:
-    # Python 3
-    from html.parser import HTMLParser
-except ImportError:
-    # Python 2
-    from HTMLParser import HTMLParser
 
 class CaseWidget(Widget):
     """Widget to test dependency traversal"""
@@ -38,7 +32,7 @@ class CaseWidget(Widget):
 class TestEmbed:
 
     def teardown(self):
-        for w in tuple(Widget.widgets.values()):
+        for w in tuple(widget_module._instances.values()):
             w.close()
 
     def test_embed_data_simple(self):
